@@ -16,8 +16,8 @@
 
 class QJsonObject;
 
-namespace KPkPass {
-
+namespace KPkPass
+{
 class BarcodePrivate;
 class Pass;
 
@@ -33,13 +33,7 @@ class KPKPASS_EXPORT Barcode
     Q_PROPERTY(QString messageEncoding READ messageEncoding CONSTANT)
 
 public:
-    enum Format {
-        Invalid,
-        QR,
-        PDF417,
-        Aztec,
-        Code128
-    };
+    enum Format { Invalid, QR, PDF417, Aztec, Code128 };
     Q_ENUM(Format)
 
     Barcode();
